from example_module.test import times_two
from example_module.test2 import times_three, times_five
from example_module.test3.test3 import times_four
from example_module.test3.test2 import times_seven
from example2.example import test
from example3.example3.example3.test import test as test_three
import unittest


class TestExample(unittest.TestCase):
    def test_seven(self):
        self.assertEqual(times_seven(4), 4*7)

    def test_three(self):
        self.assertEqual(test_three(2, 3), 5)

    def test_test(self):
        self.assertEqual(test(2, 3), 5)

    def test_five(self):
        self.assertEqual(times_five(2), 10)

    def test_two(self):
        self.assertEqual(times_two(2), 4)

    def test_three(self):
        self.assertEqual(times_three(2), 6)

    def test_four(self):
        self.assertEqual(times_four(2), 8)



import typing as tp
import warnings

from satella.coding import for_argument
from satella.files import read_lines, find_files


@for_argument(returns=list)
def find_pyx(directory_path: str) -> tp.List[str]:
    """
    Return all .pyx files found in given directory.

    :param directory_path: directory to look through
    :return: .pyx files found
    """
    warnings.warn('This is deprecated. Use find_all instead', DeprecationWarning)
    return find_files(directory_path, '(.*)\\.pyx$', scan_subdirectories=True)


@for_argument(returns=list)
def find_c(directory_path: str) -> tp.List[str]:
    """
    Return all .c files found in given directory.

    :param directory_path: directory to look through
    :return: .c files found
    """
    warnings.warn('This is deprecated. Use find_all instead', DeprecationWarning)
    return find_files(directory_path, '(.*)\\.c$', scan_subdirectories=True)


def find_pyx_and_c(directory_path: str) -> tp.List[str]:
    """
    Return a list of all .pyx and .c files found in given directory.

    :param directory_path:
    :return: list of all .pyx and .c files found in given directory
    """
    warnings.warn('This is deprecated. Use find_all instead', DeprecationWarning)
    files = find_pyx(directory_path)
    files.extend(find_c(directory_path))
    return files


def read_requirements_txt(path: str = 'requirements.txt'):
    """
    Read requirements.txt and parse it into a list of packages
    as given by setup(install_required=).

    This means it will read in all lines, discard empty and commented ones,
    and discard all those who are an URL.

    Remember to include your requirements.txt inside your MANIFEST.in!

    :param path: path to requirements.txt. Default is `requirements.txt`.
    :return: list of packages ready to be fed to setup(install_requires=)
    """
    lines = read_lines(path)
    lines = (line.strip() for line in lines)
    lines = (line for line in lines if not line.startswith('#'))
    lines = (line for line in lines if not line.startswith('git+'))
    lines = (line for line in lines if not line.startswith('http'))
    lines = (line for line in lines if line)
    return list(lines)



import pkg_resources
from .build import build
from .multibuild import Multibuild, find_all
from .faster_builds import monkey_patch_parallel_compilation
from .requirements import read_requirements_txt, find_c, find_pyx_and_c, find_pyx

try:
    __version__ = pkg_resources.require('snakehouse')[0].version
except pkg_resources.DistributionNotFound:
    __version__ = '1.6'
